pub struct RedisMessageBusBacking {
pub trader_id: TraderId,
pub instance_id: UUID4,
/* private fields */
}Fields
trader_id: TraderIdThe trader ID for this message bus backing.
instance_id: UUID4The instance ID for this message bus backing.
Implementations
Sourceimpl RedisMessageBusBacking
impl RedisMessageBusBacking
Sourcepub fn new(
trader_id: TraderId,
instance_id: UUID4,
config: MessageBusConfig,
backing: RedisMessageBusConfig,
) -> Result<Self>
pub fn new( trader_id: TraderId, instance_id: UUID4, config: MessageBusConfig, backing: RedisMessageBusConfig, ) -> Result<Self>
Creates a new RedisMessageBusBacking instance for the given trader_id, instance_id, and config.
Errors
Returns an error if the heartbeat interval is configured as zero seconds.
Sourceimpl RedisMessageBusBacking
impl RedisMessageBusBacking
Sourcepub fn get_stream_receiver(&mut self) -> Result<Receiver<BusMessage>>
pub fn get_stream_receiver(&mut self) -> Result<Receiver<BusMessage>>
Retrieves the Redis stream receiver for this message bus instance.
Errors
Returns an error if the stream receiver has already been taken.
Sourcepub fn stream(
stream_rx: Receiver<BusMessage>,
) -> impl Stream<Item = BusMessage> + 'static
pub fn stream( stream_rx: Receiver<BusMessage>, ) -> impl Stream<Item = BusMessage> + 'static
Streams messages arriving on the stream receiver channel.
pub async fn close_async(&mut self)